@@ -8,7 +8,7 @@
 .onAttach <- function(libname, pkgname)
 #.First.lib <- function(libname, pkgname)
 {
-   library.dynam("glmmAK", pkgname, libname)
+   ###library.dynam("glmmAK", pkgname, libname)   ## no more needed, load is provided by useDynLib in NAMESPACE
 
    packageStartupMessage(paste(
        "\n",
